@@ -5,13 +5,14 @@ use warnings;
 use 5.010_001;
 use Carp qw(croak);
 
-use version; our $VERSION = 'v0.3.2';
+use version; our $VERSION = 'v0.4.0';
 
 sub instance     { croak 'Must implement in child class!'; }
 sub gets         { croak 'Must implement in child class!'; }
 sub get_by_id    { croak 'Must implement in child class!'; }
 sub create       { croak 'Must implement in child class!'; }
 sub update_by_id { croak 'Must implement in child class!'; }
+sub delete_by_id { croak 'Must implement in child class!'; }
 
 1;
 
@@ -33,6 +34,7 @@ B<App::Koyomi::DataSource::Job> - Abstract datasource class for job entity
     sub get_by_id { ... }
     sub create { ... }
     sub update_by_id { ... }
+    sub delete_by_id { ... }
 
 =head1 DESCRIPTION
 
@@ -63,6 +65,10 @@ Create one job data including job_times data.
 
 Update one job data including job_times data.
 
+=item B<delete_by_id>
+
+Delete one job data including job_times data.
+
 =back
 
 =head1 SEE ALSO
